from setuptools import setup

setup(name='tbl7_lib',
      version='0.0',
      description='initial_own_package',
      packages=['tbl7_lib'],
      author_email='tomblanke1@gmail.com',
      zip_safe=False)
